#!/bin/bash
SERVER_DIR="sysom_server"
TARGET_PATH=${SERVER_HOME}/target
MIGRATION_DIR=${SERVER_DIR}/sysom_migration
VIRTUALENV_HOME=${SERVER_HOME}/virtualenv
SERVICE_NAME=sysom-migration
ANCE_X86_PKG=ance-0.1.1-1.x86_64.rpm
ANCE_ARM_PKG=ance-0.1.1-1.aarch64.rpm
ANOLIS_X86_SQLITE=Anolis_OS-8.6.x86_64.sqlite
ANOLIS_ARM_SQLITE=Anolis_OS-8.6.aarch64.sqlite
ANOLIS_MIGRATION_PKGS_X86=anolis_migration_pkgs_x86_64.tar.gz
ANOLIS_MIGRATION_PKGS_ARM=anolis_migration_pkgs_aarch64.tar.gz

if [ "$UID" -ne 0 ]; then
    echo "Please run as root"
    exit 1
fi

source_virtualenv() {
    echo "INFO: activate virtualenv..."
    source ${VIRTUALENV_HOME}/bin/activate || exit 1
}

init_conf() {
    pushd ${TARGET_PATH}/${MIGRATION_DIR}
    python manage.py migrate
    popd

    cp ${SERVICE_NAME}.ini /etc/supervisord.d/
    ###change the install dir base on param $1###
    sed -i "s;/usr/local/sysom;${APP_HOME};g" /etc/supervisord.d/${SERVICE_NAME}.ini
    cpu_num=`cat /proc/cpuinfo | grep processor | wc -l`
    sed -i "s/threads = 3/threads = $cpu_num/g" ${TARGET_PATH}/${MIGRATION_DIR}/conf/migration_gunicorn.py
}

check_or_download_ance() {
    mkdir -p ${TARGET_PATH}/${MIGRATION_DIR}/ance
    pushd ${TARGET_PATH}/${MIGRATION_DIR}/ance
    if [ ! -f "${ANCE_X86_PKG}" ]; then
        wget "https://ance.oss-cn-hangzhou.aliyuncs.com/release/x86_64/${ANCE_X86_PKG}"
    fi
    if [ ! -f "${ANCE_ARM_PKG}" ]; then
        wget "https://ance.oss-cn-hangzhou.aliyuncs.com/release/aarch64/${ANCE_ARM_PKG}"
    fi
    if [ ! -f "${ANOLIS_X86_SQLITE}" ]; then
        wget "https://ance.oss-cn-hangzhou.aliyuncs.com/databases/${ANOLIS_X86_SQLITE}"
    fi
    if [ ! -f "${ANOLIS_ARM_SQLITE}" ]; then
        wget "https://ance.oss-cn-hangzhou.aliyuncs.com/databases/${ANOLIS_ARM_SQLITE}"
    fi
    if [ ! -f "${ANOLIS_MIGRATION_PKGS_X86}" ]; then
        wget "https://gitee.com/src-anolis-sig/leapp/releases/download/v1.0.2-all-in-one/${ANOLIS_MIGRATION_PKGS_X86}"
    fi
    if [ ! -f "${ANOLIS_MIGRATION_PKGS_ARM}" ]; then
        wget "https://gitee.com/src-anolis-sig/leapp/releases/download/v1.0.2-all-in-one/${ANOLIS_MIGRATION_PKGS_ARM}"
    fi
    popd
}

start_app() {
    ###if supervisor service started, we need use "supervisorctl update" to start new conf####
    supervisorctl update
    supervisorctl status ${SERVICE_NAME}
    if [ $? -eq 0 ]
    then
        echo "supervisorctl start ${SERVICE_NAME} success..."
        return 0
    fi
    echo "${SERVICE_NAME} service start fail, please check log"
    exit 1
}

deploy() {
    source_virtualenv
    init_conf
    check_or_download_ance
    start_app
}

deploy
